@@ -10,8 +10,8 @@ from __future__ import unicode_literals
 import itertools
 
 import pytest
-from typepy import StrictLevel, Typecode
-from typepy.type import List
+
+from typepy import List, StrictLevel, Typecode
 
 
 nan = float("nan")
@@ -19,7 +19,6 @@ inf = float("inf")
 
 
 class Test_List_is_type(object):
-
     @pytest.mark.parametrize(
         ["value", "strict_level", "expected"],
         [
@@ -27,15 +26,14 @@ class Test_List_is_type(object):
             [("a", 1), StrictLevel.MAX, False],
             [{"a": 1, "b": 2}, StrictLevel.MIN, True],
             [{"a": 1, "b": 2}, StrictLevel.MAX, False],
-        ] + list(itertools.product(
-            [[], ["a", 1]],
-            [StrictLevel.MIN, StrictLevel.MAX],
-            [True],
-        )) + list(itertools.product(
-            [(), {}, "", "abc", 1, nan, True, None],
-            [StrictLevel.MIN, StrictLevel.MAX],
-            [False],
-        )))
+        ]
+        + list(itertools.product([[], ["a", 1]], [StrictLevel.MIN, StrictLevel.MAX], [True]))
+        + list(
+            itertools.product(
+                [(), {}, "", "abc", 1, nan, True, None], [StrictLevel.MIN, StrictLevel.MAX], [False]
+            )
+        ),
+    )
     def test_normal(self, value, strict_level, expected):
         type_object = List(value, strict_level)
 
