@@ -9,6 +9,7 @@ from __future__ import absolute_import, unicode_literals
 import warnings
 
 from ._const import StrictLevel
+from .type import NullString, String
 
 
 def is_hex(value):
@@ -20,36 +21,28 @@ def is_hex(value):
     return True
 
 
-def is_list_or_tuple(value):
-    return isinstance(value, (tuple, list))
-
-
 def is_null_string(value):
-    from .type import NullString
-
     return NullString(value, strict_level=StrictLevel.MIN).is_type()
 
 
 def is_not_null_string(value):
-    from .type import String
-
     return String(value, strict_level=StrictLevel.MAX).is_type()
 
 
 def is_empty_string(value):
     warnings.warn(
-        "is_empty_string() will be deleted in the future, "
-        "use is_null_string instead.",
-        DeprecationWarning)
+        "is_empty_string() will be deleted in the future, " "use is_null_string instead.",
+        DeprecationWarning,
+    )
 
     return is_null_string(value)
 
 
 def is_not_empty_string(value):
     warnings.warn(
-        "is_not_empty_string() will be deleted in the future, "
-        "use is_not_null_string instead.",
-        DeprecationWarning)
+        "is_not_empty_string() will be deleted in the future, " "use is_not_null_string instead.",
+        DeprecationWarning,
+    )
 
     return is_not_null_string(value)
 
