@@ -11,13 +11,8 @@ import abc
 from ._interface import TypeCheckerInterface
 
 
-class CheckerCreator(object):
-    __slots__ = (
-        "__min_strict_level",
-        "__max_strict_level",
-        "__value",
-        "__checker_mapping",
-    )
+class CheckerFactory(object):
+    __slots__ = ("__min_strict_level", "__max_strict_level", "__checker_mapping")
 
     @property
     def min_strict_level(self):
@@ -27,28 +22,27 @@ class CheckerCreator(object):
     def max_strict_level(self):
         return self.__max_strict_level
 
-    def __init__(self, value, checker_mapping):
-        self.__value = value
+    def __init__(self, checker_mapping):
         self.__checker_mapping = checker_mapping
 
         self.__min_strict_level = min(checker_mapping)
         self.__max_strict_level = max(checker_mapping)
+        self.__checker_mapping[None] = self.__max_strict_level
 
-    def create(self, strict_level=None):
-        if strict_level is None:
-            strict_level = self.max_strict_level
-        elif strict_level < self.min_strict_level:
-            strict_level = self.min_strict_level
-        elif strict_level > self.max_strict_level:
-            strict_level = self.max_strict_level
+    def get_checker_class(self, strict_level=None):
+        checker_class = self.__checker_mapping.get(strict_level)
+        if checker_class:
+            return checker_class
+        if strict_level < self.min_strict_level:
+            return self.__checker_mapping[self.min_strict_level]
+        if strict_level > self.max_strict_level:
+            return self.__checker_mapping[self.max_strict_level]
 
-        return self.__checker_mapping.get(strict_level)(self.__value)
+        raise ValueError("unexpected strict level: {}".format(strict_level))
 
 
-class TypeCheckerStrictLevel(TypeCheckerInterface):
-    __slots__ = (
-        "_value",
-    )
+class TypeCheckerBase(TypeCheckerInterface):
+    __slots__ = ("_value",)
 
     def __init__(self, value):
         self._value = value
@@ -69,8 +63,7 @@ class TypeCheckerStrictLevel(TypeCheckerInterface):
         if self.is_type():
             return
 
-        raise TypeError(
-            "invalid value type: actual={}".format(type(self._value)))
+        raise TypeError("invalid value type: actual={}".format(type(self._value)))
 
     def is_exclude_instance(self):
         return False
@@ -79,15 +72,11 @@ class TypeCheckerStrictLevel(TypeCheckerInterface):
         return True
 
 
-class TypeChecker(TypeCheckerInterface):
-    __slots__ = (
-        "__checker",
-    )
+class TypeCheckerDelegator(TypeCheckerInterface):
+    __slots__ = ("__checker",)
 
-    def __init__(self, value, checker_mapping, strict_level):
-        self.__checker = CheckerCreator(
-            value=value,
-            checker_mapping=checker_mapping).create(strict_level)
+    def __init__(self, value, checker_factory, strict_level):
+        self.__checker = checker_factory.get_checker_class(strict_level)(value)
 
     def is_type(self):
         return self.__checker.is_type()
