@@ -6,11 +6,10 @@
 
 from __future__ import absolute_import
 
-from ._checker import TypeChecker, TypeCheckerStrictLevel
+from ._checker import CheckerFactory, TypeCheckerBase, TypeCheckerDelegator
 
 
-class DictionaryTypeCheckerStrictLevel0(TypeCheckerStrictLevel):
-
+class DictionaryTypeCheckerStrictLevel0(TypeCheckerBase):
     def is_instance(self):
         return isinstance(self._value, dict)
 
@@ -19,18 +18,17 @@ class DictionaryTypeCheckerStrictLevel0(TypeCheckerStrictLevel):
 
 
 class DictionaryTypeCheckerStrictLevel1(DictionaryTypeCheckerStrictLevel0):
-
     def is_exclude_instance(self):
         return not isinstance(self._value, dict)
 
 
-class DictionaryTypeChecker(TypeChecker):
+_factory = CheckerFactory(
+    checker_mapping={0: DictionaryTypeCheckerStrictLevel0, 1: DictionaryTypeCheckerStrictLevel1}
+)
 
+
+class DictionaryTypeChecker(TypeCheckerDelegator):
     def __init__(self, value, strict_level):
         super(DictionaryTypeChecker, self).__init__(
-            value=value,
-            checker_mapping={
-                0: DictionaryTypeCheckerStrictLevel0,
-                1: DictionaryTypeCheckerStrictLevel1,
-            },
-            strict_level=strict_level)
+            value=value, checker_factory=_factory, strict_level=strict_level
+        )
