@@ -6,12 +6,11 @@
 
 from __future__ import absolute_import
 
-from ._checker import TypeChecker, TypeCheckerStrictLevel
+from ._checker import CheckerFactory, TypeCheckerBase, TypeCheckerDelegator
 from ._common import isinf, isstring
 
 
-class InfinityCheckerStrictLevel0(TypeCheckerStrictLevel):
-
+class InfinityCheckerStrictLevel0(TypeCheckerBase):
     def is_instance(self):
         return isinf(self._value)
 
@@ -23,18 +22,17 @@ class InfinityCheckerStrictLevel0(TypeCheckerStrictLevel):
 
 
 class InfinityCheckerStrictLevel1(InfinityCheckerStrictLevel0):
-
     def is_exclude_instance(self):
         return isstring(self._value)
 
 
-class InfinityTypeChecker(TypeChecker):
+_factory = CheckerFactory(
+    checker_mapping={0: InfinityCheckerStrictLevel0, 1: InfinityCheckerStrictLevel1}
+)
 
+
+class InfinityTypeChecker(TypeCheckerDelegator):
     def __init__(self, value, strict_level):
         super(InfinityTypeChecker, self).__init__(
-            value=value,
-            checker_mapping={
-                0: InfinityCheckerStrictLevel0,
-                1: InfinityCheckerStrictLevel1,
-            },
-            strict_level=strict_level)
+            value=value, checker_factory=_factory, strict_level=strict_level
+        )
