@@ -6,12 +6,11 @@
 
 from __future__ import absolute_import
 
-from ._checker import TypeChecker, TypeCheckerStrictLevel
+from ._checker import CheckerFactory, TypeCheckerBase, TypeCheckerDelegator
 from ._common import isstring
 
 
-class IpAddressTypeCheckerStrictLevel0(TypeCheckerStrictLevel):
-
+class IpAddressTypeCheckerStrictLevel0(TypeCheckerBase):
     def is_instance(self):
         return self._is_ipaddress(self._value)
 
@@ -22,26 +21,24 @@ class IpAddressTypeCheckerStrictLevel0(TypeCheckerStrictLevel):
     def _is_ipaddress(value):
         import ipaddress
 
-        return isinstance(
-            value, (ipaddress.IPv4Address, ipaddress.IPv6Address))
+        return isinstance(value, (ipaddress.IPv4Address, ipaddress.IPv6Address))
 
 
 class IpAddressTypeCheckerStrictLevel1(IpAddressTypeCheckerStrictLevel0):
-
     def is_exclude_instance(self):
         return (
-            isstring(self._value) or
-            super(IpAddressTypeCheckerStrictLevel1, self).is_exclude_instance()
+            isstring(self._value)
+            or super(IpAddressTypeCheckerStrictLevel1, self).is_exclude_instance()
         )
 
 
-class IpAddressTypeChecker(TypeChecker):
+_factory = CheckerFactory(
+    checker_mapping={0: IpAddressTypeCheckerStrictLevel0, 1: IpAddressTypeCheckerStrictLevel1}
+)
 
+
+class IpAddressTypeChecker(TypeCheckerDelegator):
     def __init__(self, value, strict_level):
         super(IpAddressTypeChecker, self).__init__(
-            value=value,
-            checker_mapping={
-                0: IpAddressTypeCheckerStrictLevel0,
-                1: IpAddressTypeCheckerStrictLevel1,
-            },
-            strict_level=strict_level)
+            value=value, checker_factory=_factory, strict_level=strict_level
+        )
