@@ -6,12 +6,11 @@
 
 from __future__ import absolute_import
 
-from ._checker import TypeChecker, TypeCheckerStrictLevel
+from ._checker import CheckerFactory, TypeCheckerBase, TypeCheckerDelegator
 from ._common import isstring
 
 
-class ListTypeCheckerStrictLevel0(TypeCheckerStrictLevel):
-
+class ListTypeCheckerStrictLevel0(TypeCheckerBase):
     def is_instance(self):
         return isinstance(self._value, list)
 
@@ -23,21 +22,19 @@ class ListTypeCheckerStrictLevel0(TypeCheckerStrictLevel):
 
 
 class ListTypeCheckerStrictLevel1(ListTypeCheckerStrictLevel0):
-
     def is_exclude_instance(self):
-        return (
-            super(ListTypeCheckerStrictLevel1, self).is_exclude_instance() or
-            not isinstance(self._value, list)
+        return super(ListTypeCheckerStrictLevel1, self).is_exclude_instance() or not isinstance(
+            self._value, list
         )
 
 
-class ListTypeChecker(TypeChecker):
+_factory = CheckerFactory(
+    checker_mapping={0: ListTypeCheckerStrictLevel0, 1: ListTypeCheckerStrictLevel1}
+)
 
+
+class ListTypeChecker(TypeCheckerDelegator):
     def __init__(self, value, strict_level):
         super(ListTypeChecker, self).__init__(
-            value=value,
-            checker_mapping={
-                0: ListTypeCheckerStrictLevel0,
-                1: ListTypeCheckerStrictLevel1,
-            },
-            strict_level=strict_level)
+            value=value, checker_factory=_factory, strict_level=strict_level
+        )
