@@ -6,12 +6,11 @@
 
 from __future__ import absolute_import
 
-from ._checker import TypeChecker, TypeCheckerStrictLevel
+from ._checker import CheckerFactory, TypeCheckerBase, TypeCheckerDelegator
 from ._common import isnan, isstring
 
 
-class NanTypeCheckerStrictLevel0(TypeCheckerStrictLevel):
-
+class NanTypeCheckerStrictLevel0(TypeCheckerBase):
     def is_instance(self):
         return isnan(self._value)
 
@@ -20,18 +19,17 @@ class NanTypeCheckerStrictLevel0(TypeCheckerStrictLevel):
 
 
 class NanTypeCheckerStrictLevel1(NanTypeCheckerStrictLevel0):
-
     def is_exclude_instance(self):
         return isstring(self._value)
 
 
-class NanTypeChecker(TypeChecker):
+_factory = CheckerFactory(
+    checker_mapping={0: NanTypeCheckerStrictLevel0, 1: NanTypeCheckerStrictLevel1}
+)
 
+
+class NanTypeChecker(TypeCheckerDelegator):
     def __init__(self, value, strict_level):
         super(NanTypeChecker, self).__init__(
-            value=value,
-            checker_mapping={
-                0: NanTypeCheckerStrictLevel0,
-                1: NanTypeCheckerStrictLevel1,
-            },
-            strict_level=strict_level)
+            value=value, checker_factory=_factory, strict_level=strict_level
+        )
