@@ -6,11 +6,10 @@
 
 from __future__ import absolute_import
 
-from ._checker import TypeChecker, TypeCheckerStrictLevel
+from ._checker import CheckerFactory, TypeCheckerBase, TypeCheckerDelegator
 
 
-class NoneTypeCheckerStrictLevel0(TypeCheckerStrictLevel):
-
+class NoneTypeCheckerStrictLevel0(TypeCheckerBase):
     def is_instance(self):
         return self._value is None
 
@@ -18,12 +17,11 @@ class NoneTypeCheckerStrictLevel0(TypeCheckerStrictLevel):
         return self._value is None
 
 
-class NoneTypeChecker(TypeChecker):
+_factory = CheckerFactory(checker_mapping={0: NoneTypeCheckerStrictLevel0})
 
+
+class NoneTypeChecker(TypeCheckerDelegator):
     def __init__(self, value, strict_level):
         super(NoneTypeChecker, self).__init__(
-            value=value,
-            checker_mapping={
-                0: NoneTypeCheckerStrictLevel0,
-            },
-            strict_level=strict_level)
+            value=value, checker_factory=_factory, strict_level=strict_level
+        )
