@@ -6,12 +6,11 @@
 
 from __future__ import absolute_import
 
-from ._checker import TypeChecker, TypeCheckerStrictLevel
+from ._checker import CheckerFactory, TypeCheckerBase, TypeCheckerDelegator
 from ._common import isstring
 
 
-class StringTypeCheckerStrictLevel0(TypeCheckerStrictLevel):
-
+class StringTypeCheckerStrictLevel0(TypeCheckerBase):
     def is_instance(self):
         return isstring(self._value)
 
@@ -28,28 +27,35 @@ class StringTypeCheckerStrictLevel0(TypeCheckerStrictLevel):
 
 
 class StringTypeCheckerStrictLevel1(StringTypeCheckerStrictLevel0):
-
     def is_exclude_instance(self):
-        return (
-            not isstring(self._value) or
-            self._is_null_string(self._value)
+        return not isstring(self._value)
+
+
+class StringTypeCheckerStrictLevel2(StringTypeCheckerStrictLevel1):
+    def is_exclude_instance(self):
+        if super(StringTypeCheckerStrictLevel2, self).is_exclude_instance():
+            return True
+
+        return self._is_null_string(self._value)
+
+
+_string_factory = CheckerFactory(
+    checker_mapping={
+        0: StringTypeCheckerStrictLevel0,
+        1: StringTypeCheckerStrictLevel1,
+        2: StringTypeCheckerStrictLevel2,
+    }
+)
+
+
+class StringTypeChecker(TypeCheckerDelegator):
+    def __init__(self, value, strict_level):
+        super(StringTypeChecker, self).__init__(
+            value=value, checker_factory=_string_factory, strict_level=strict_level
         )
 
 
-class StringTypeChecker(TypeChecker):
-
-    def __init__(self, value, strict_level):
-        super(StringTypeChecker, self).__init__(
-            value=value,
-            checker_mapping={
-                0: StringTypeCheckerStrictLevel0,
-                1: StringTypeCheckerStrictLevel1,
-            },
-            strict_level=strict_level)
-
-
 class NullStringTypeCheckerStrictLevel0(StringTypeCheckerStrictLevel0):
-
     def is_instance(self):
         return self._value is None
 
@@ -58,18 +64,17 @@ class NullStringTypeCheckerStrictLevel0(StringTypeCheckerStrictLevel0):
 
 
 class NullStringTypeCheckerStrictLevel1(NullStringTypeCheckerStrictLevel0):
-
     def is_instance(self):
         return False
 
 
-class NullStringTypeChecker(TypeChecker):
+_null_string_factory = CheckerFactory(
+    checker_mapping={0: NullStringTypeCheckerStrictLevel0, 1: NullStringTypeCheckerStrictLevel1}
+)
 
+
+class NullStringTypeChecker(TypeCheckerDelegator):
     def __init__(self, value, strict_level):
         super(NullStringTypeChecker, self).__init__(
-            value=value,
-            checker_mapping={
-                0: NullStringTypeCheckerStrictLevel0,
-                1: NullStringTypeCheckerStrictLevel1,
-            },
-            strict_level=strict_level)
+            value=value, checker_factory=_null_string_factory, strict_level=strict_level
+        )
