@@ -6,6 +6,7 @@
 
 from __future__ import absolute_import
 
+from ._binary import BinaryConverter
 from ._bool import BoolConverter
 from ._datetime import DateTimeConverter
 from ._dictionary import DictionaryConverter
@@ -15,7 +16,4 @@ from ._ipaddress import IpAddressConverter
 from ._list import ListConverter
 from ._nop import NopConverter
 from ._realnumber import FloatConverter
-from ._string import (
-    StringConverter,
-    NullStringConverter,
-)
+from ._string import NullStringConverter, StringConverter
