@@ -8,12 +8,13 @@ from __future__ import absolute_import, unicode_literals
 
 import six
 
-from .._error import TypeConversionError
+from .._common import strip_ansi_escape
+from .._const import DefaultValue, ParamKey
+from ..error import TypeConversionError
 from ._interface import AbstractValueConverter
 
 
 class BoolConverter(AbstractValueConverter):
-
     def force_convert(self):
         if isinstance(self._value, six.integer_types):
             return bool(self._value)
@@ -21,9 +22,17 @@ class BoolConverter(AbstractValueConverter):
         try:
             return self.__strict_strtobool(self._value)
         except ValueError:
-            raise TypeConversionError(
-                "failed to force_convert to bool: type={}".format(
-                    type(self._value)))
+            pass
+
+        if self._params.get(ParamKey.STRIP_ANSI_ESCAPE, DefaultValue.STRIP_ANSI_ESCAPE):
+            try:
+                return self.__strict_strtobool(strip_ansi_escape(self._value))
+            except (TypeError, ValueError):
+                pass
+
+        raise TypeConversionError(
+            "failed to force_convert to bool: type={}".format(type(self._value))
+        )
 
     @staticmethod
     def __strict_strtobool(value):
