@@ -6,10 +6,12 @@
 
 from __future__ import absolute_import, unicode_literals
 
-import re
-from datetime import datetime
+from datetime import date, datetime
+from distutils.version import StrictVersion
 
-from .._error import TypeConversionError
+from .._common import strip_ansi_escape
+from .._const import DefaultValue, ParamKey
+from ..error import TypeConversionError
 from ._interface import AbstractValueConverter
 
 
@@ -30,13 +32,11 @@ class DateTimeConverter(AbstractValueConverter):
         7200: "Africa/Tripoli",  # 0200
     }
 
-    __RE_VERSION_STR = re.compile("\d+\.\d+\.\d")
-
-    def __init__(self, value, timezone=None):
-        super(DateTimeConverter, self).__init__(value)
+    def __init__(self, value, params):
+        super(DateTimeConverter, self).__init__(value, params)
 
         self.__datetime = None
-        self.__timezone = timezone
+        self.__timezone = self._params.get(ParamKey.TIMEZONE)
 
     def force_convert(self):
         self.__datetime = self.__from_datetime()
@@ -50,10 +50,16 @@ class DateTimeConverter(AbstractValueConverter):
         return self.__from_datetime_string()
 
     def __from_datetime(self):
-        if not isinstance(self._value, datetime):
+        if not isinstance(self._value, (date, datetime)):
             return None
 
-        self.__datetime = self._value
+        if isinstance(self._value, datetime):
+            self.__datetime = self._value
+        elif isinstance(self._value, date):
+            self.__datetime = datetime(
+                year=self._value.year, month=self._value.month, day=self._value.day
+            )
+
         if self.__timezone:
             self.__datetime = self.__timezone.localize(self.__datetime)
 
@@ -61,19 +67,33 @@ class DateTimeConverter(AbstractValueConverter):
 
     def __from_timestamp(self):
         from ..type._integer import Integer
+        from ..type._realnumber import RealNumber
+
+        conv_error = TypeConversionError(
+            "timestamp is out of the range of values supported by the platform"
+        )
 
         timestamp = Integer(self._value, strict_level=1).try_convert()
-        if timestamp is None:
-            return None
+        if timestamp:
+            try:
+                self.__datetime = datetime.fromtimestamp(timestamp, self.__timezone)
+            except (ValueError, OSError, OverflowError):
+                raise conv_error
 
-        try:
-            self.__datetime = datetime.fromtimestamp(
-                timestamp, self.__timezone)
-        except (ValueError, OSError, OverflowError):
-            raise TypeConversionError(
-                "timestamp is out of the range of values supported by the platform")
+            return self.__datetime
 
-        return self.__datetime
+        timestamp = RealNumber(self._value, strict_level=1).try_convert()
+        if timestamp:
+            try:
+                self.__datetime = datetime.fromtimestamp(int(timestamp), self.__timezone).replace(
+                    microsecond=int((timestamp - int(timestamp)) * 1000000)
+                )
+            except (ValueError, OSError, OverflowError):
+                raise conv_error
+
+            return self.__datetime
+
+        return None
 
     def __from_datetime_string(self):
         import dateutil.parser
@@ -84,16 +104,22 @@ class DateTimeConverter(AbstractValueConverter):
         try:
             self.__datetime = dateutil.parser.parse(self._value)
         except (AttributeError, ValueError, OverflowError):
+            if self._params.get(ParamKey.STRIP_ANSI_ESCAPE, DefaultValue.STRIP_ANSI_ESCAPE):
+                try:
+                    self.__datetime = dateutil.parser.parse(strip_ansi_escape(self._value))
+                except (AttributeError, ValueError, OverflowError):
+                    pass
+
+        if self.__datetime is None:
             raise TypeConversionError(
-                "failed to parse as a datetime: type={}".format(
-                    type(self._value)))
+                "failed to parse as a datetime: type={}".format(type(self._value))
+            )
 
         if self.__timezone:
             pytz_timezone = self.__timezone
         else:
             try:
-                dst_timezone_name = self.__get_dst_timezone_name(
-                    self.__get_timedelta_sec())
+                dst_timezone_name = self.__get_dst_timezone_name(self.__get_timedelta_sec())
             except (AttributeError, KeyError):
                 return self.__datetime
 
@@ -108,12 +134,9 @@ class DateTimeConverter(AbstractValueConverter):
         dt = self.__datetime.utcoffset()
 
         return int(
-            (
-                dt.days *
-                self.__DAYS_TO_SECONDS_COEF +
-                float(dt.seconds)
-            ) +
-            dt.microseconds / self.__MICROSECONDS_TO_SECONDS_COEF
+            dt.days * self.__DAYS_TO_SECONDS_COEF
+            + float(dt.seconds)
+            + dt.microseconds / self.__MICROSECONDS_TO_SECONDS_COEF
         )
 
     def __get_dst_timezone_name(self, offset):
@@ -127,10 +150,12 @@ class DateTimeConverter(AbstractValueConverter):
         """
 
         try:
-            if self.__RE_VERSION_STR.search(self._value) is not None:
+            try:
+                StrictVersion(self._value)
                 raise TypeConversionError(
-                    "invalid datetime string: version string found " +
-                    self._value)
+                    "invalid datetime string: version string found {}".format(self._value)
+                )
+            except ValueError:
+                pass
         except TypeError:
-            raise TypeConversionError(
-                "invalid datetime string: type={}".format(type(self._value)))
+            raise TypeConversionError("invalid datetime string: type={}".format(type(self._value)))
