@@ -10,22 +10,22 @@ import abc
 
 import six
 
-from .._error import TypeConversionError
+from ..error import TypeConversionError
 
 
 @six.add_metaclass(abc.ABCMeta)
 class ValueConverterInterface(object):
-
     @abc.abstractmethod
     def force_convert(self):  # pragma: no cover
         pass
 
 
 class AbstractValueConverter(ValueConverterInterface):
-    __slots__ = ("_value")
+    __slots__ = "_value"
 
-    def __init__(self, value):
+    def __init__(self, value, params):
         self._value = value
+        self._params = params
 
     def __repr__(self):
         try:
