@@ -6,6 +6,8 @@
 
 from __future__ import absolute_import
 
+from ._base import AbstractType
+from ._binary import Binary
 from ._bool import Bool
 from ._datetime import DateTime
 from ._dictionary import Dictionary
@@ -16,7 +18,4 @@ from ._list import List
 from ._nan import Nan
 from ._none import NoneType
 from ._realnumber import RealNumber
-from ._string import (
-    String,
-    NullString,
-)
+from ._string import NullString, String
