@@ -8,15 +8,18 @@ from __future__ import absolute_import, unicode_literals
 
 import abc
 
-from .._error import TypeConversionError
 from ..checker._interface import TypeCheckerInterface
 from ..converter import ValueConverterInterface
+from ..error import TypeConversionError
 
 
 class AbstractType(TypeCheckerInterface, ValueConverterInterface):
     __slots__ = (
-        "_data", "_strict_level", "_params",
-        "__checker", "__converter",
+        "_data",
+        "_strict_level",
+        "_params",
+        "__checker",
+        "__converter",
         "__is_type_result",
     )
 
@@ -36,14 +39,10 @@ class AbstractType(TypeCheckerInterface, ValueConverterInterface):
     def typename(self):
         return self.typecode.name
 
-    def __init__(self, value, strict_level, params):
+    def __init__(self, value, strict_level, **kwargs):
         self._data = value
         self._strict_level = strict_level
-
-        if not params:
-            self._params = {}
-        else:
-            self._params = params
+        self._params = kwargs
 
         self.__checker = self._create_type_checker()
         self.__converter = self._create_type_converter()
@@ -51,13 +50,15 @@ class AbstractType(TypeCheckerInterface, ValueConverterInterface):
         self.__is_type_result = None
 
     def __repr__(self):
-        return ", ".join([
-            "value={}".format(self._data),
-            "typename={}".format(self.typename),
-            "strict_level={}".format(self._strict_level),
-            "is_type={}".format(self.is_type()),
-            "try_convert={}".format(self.try_convert()),
-        ])
+        return ", ".join(
+            [
+                "value={}".format(self._data),
+                "typename={}".format(self.typename),
+                "strict_level={}".format(self._strict_level),
+                "is_type={}".format(self.is_type()),
+                "try_convert={}".format(self.try_convert()),
+            ]
+        )
 
     def is_type(self):
         """
@@ -89,7 +90,7 @@ class AbstractType(TypeCheckerInterface, ValueConverterInterface):
 
         return True
 
-    def validate(self):
+    def validate(self, error_message=None):
         """
         :raises TypeError:
             If the value is not matched the type that the class represented.
@@ -98,9 +99,12 @@ class AbstractType(TypeCheckerInterface, ValueConverterInterface):
         if self.is_type():
             return
 
+        if not error_message:
+            error_message = "invalid value type"
+
         raise TypeError(
-            "invalid value type: expected={}, actual={}".format(
-                self.typecode, type(self._data)))
+            "{}: expected={}, actual={}".format(error_message, self.typename, type(self._data))
+        )
 
     def convert(self):
         """
@@ -113,8 +117,8 @@ class AbstractType(TypeCheckerInterface, ValueConverterInterface):
             return self.force_convert()
 
         raise TypeConversionError(
-            "failed to convert from {} to {}".format(
-                type(self._data).__name__, self.typename))
+            "failed to convert from {} to {}".format(type(self._data).__name__, self.typename)
+        )
 
     def force_convert(self):
         """
