@@ -7,8 +7,6 @@
 from __future__ import absolute_import
 
 from .._typecode import Typecode
-from ..checker._bool import BoolTypeChecker
-from ..converter._bool import BoolConverter
 from ._base import AbstractType
 
 
@@ -28,10 +26,14 @@ class Bool(AbstractType):
         return Typecode.BOOL
 
     def __init__(self, value, strict_level=2, **kwargs):
-        super(Bool, self).__init__(value, strict_level, kwargs)
+        super(Bool, self).__init__(value, strict_level, **kwargs)
 
     def _create_type_checker(self):
+        from ..checker._bool import BoolTypeChecker
+
         return BoolTypeChecker(self._data, self._strict_level)
 
     def _create_type_converter(self):
-        return BoolConverter(self._data)
+        from ..converter._bool import BoolConverter
+
+        return BoolConverter(self._data, self._params)
