@@ -22,18 +22,15 @@ class DateTime(AbstractType):
         |strict_level|
     """
 
-    _TIMEZONE_KEY = "timezone"
-
     @property
     def typecode(self):
         return Typecode.DATETIME
 
     def __init__(self, value, strict_level=2, **kwargs):
-        super(DateTime, self).__init__(value, strict_level, kwargs)
+        super(DateTime, self).__init__(value, strict_level, **kwargs)
 
     def _create_type_checker(self):
         return DateTimeTypeChecker(self._data, self._strict_level)
 
     def _create_type_converter(self):
-        return DateTimeConverter(
-            self._data, self._params.get(self._TIMEZONE_KEY))
+        return DateTimeConverter(self._data, self._params)
