@@ -8,8 +8,6 @@ from __future__ import absolute_import, unicode_literals
 
 from .._const import DefaultValue
 from .._typecode import Typecode
-from ..checker._realnumber import RealNumberTypeChecker
-from ..converter._realnumber import FloatConverter
 from ._base import AbstractType
 
 
@@ -28,14 +26,17 @@ class RealNumber(AbstractType):
         return Typecode.REAL_NUMBER
 
     def __init__(self, value, strict_level=0, **kwargs):
-        super(RealNumber, self).__init__(value, strict_level, kwargs)
+        super(RealNumber, self).__init__(value, strict_level, **kwargs)
 
     def _create_type_checker(self):
+        from ..checker._realnumber import RealNumberTypeChecker
+
         return RealNumberTypeChecker(self._data, self._strict_level)
 
     def _create_type_converter(self):
-        converter = FloatConverter(self._data)
-        converter.float_class = self._params.get(
-            "float_type", DefaultValue.FLOAT_TYPE)
+        from ..converter._realnumber import FloatConverter
+
+        converter = FloatConverter(self._data, self._params)
+        converter.float_class = self._params.get("float_type", DefaultValue.FLOAT_TYPE)
 
         return converter
